DigestAlgorithm

Trait DigestAlgorithm 

pub trait DigestAlgorithm: EcdsaCurve {
    type Digest: BlockSizeUser + Digest + FixedOutput + FixedOutputReset;
}
Bind a preferred Digest algorithm to an elliptic curve type.

Generally there is a preferred variety of the SHA-2 family used with ECDSA for a particular elliptic curve.

Required Associated Types

type Digest: BlockSizeUser + Digest + FixedOutput + FixedOutputReset

Preferred digest to use when computing ECDSA signatures for this elliptic curve. This is typically a member of the SHA-2 family.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors